@@ -1,5 +1,6 @@
 """Object-specific python package to run automated tasks in the Chase Lab."""
-import warnings; warnings.filterwarnings("ignore")
+from .recycle import *
+
 from .ffsync import ffsync
 from .ffconcat import ffconcat
 from .lazytrim import lazytrim
@@ -7,7 +8,6 @@ from .improve_dlc_output import improve_dlc_output
 from .improve_dlc_csv import improve_dlc_csv
 from .improve_dlc_output_cat_alone import improve_dlc_output_cat_alone
 from .csv2h5 import csv2h5
-from .recycle import *
 from .analyze_rois import analyze_rois
 from .concat_rois import concat_rois
 from .roi_calc_mw import roi_calc_mw
@@ -18,4 +18,9 @@ from .calc_dlc_mw import calc_dlc_mw
 from .dlcboxplot import dlcboxplot
 from .turning_points import turning_points_output
 from .improve_turnpoints import improve_turnpoints
+from .std_cols import std_cols
+from .turnpoints_time_diff import turnpoints_time_diff
+from .find_tps_velocity_values import find_tps_velocity_values
+from .fwarnings import fwarnings
+
 from .version import __version__, VERSION
