@@ -4,6 +4,7 @@ Toxopy (https://github.com/bchaselab/Toxopy)
 Licensed under the terms of the MIT license
 """
 
+
 def trials_full():
 
     return [
@@ -13,6 +14,11 @@ def trials_full():
     ]
 
 
+def trials_cap():
+
+	return ['No treatment', 'Cat alone (1)', 'First Saline', 'Cat alone (2)', 'First Urine', 'Cat alone (3)', 'Second Saline', 'Cat alone (4)', 'Second Urine', 'Cat alone (5)']
+
+
 def trials():
 
     return ['FT', 'CA1', 'ST1', 'CA2', 'UT1', 'CA3', 'ST2', 'CA4', 'UT2', 'CA5']
